/**
 *  Copyright notice
 *  
 *  This file is part of the Processing sketch `CavityCalculator' 
 *  http://www.gwoptics.org/processing/cavity_calculator/
 *
 *  Copyright (C) 2010 onwards Jamie Dougherty and Andreas Freise
 *  
 *  This program is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU General Public License
 *  as published by the Free Software Foundation; either version 2
 *  of the License, or (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, 
 *  MA  02110-1301, USA.
 */

class LEDMeterAxis {
    
  //Primary variables
  int x_pos, y_pos;
  int num_labels;
  float step_size, minimum, maximum;
  int x_step;
 
  // Secondary variables
  int font_size, scale_factor;
  PFont font;
  color text_colour;
  boolean text_colour_set;
 
  LEDMeterAxis(int t_x_pos, int t_y_pos, int t_num_labels, int t_x_step, 
              float t_minimum, float t_maximum) {
              
              x_pos = t_x_pos;
              y_pos = t_y_pos;
              num_labels = t_num_labels;
              x_step = t_x_step;
              minimum = t_minimum;
              maximum = t_maximum;
              
              step_size = (maximum - minimum)/(float)num_labels;
              
              scale_factor = 1;
              
              pushStyle();
              fontSize(); 
              
              font = createFont("Ariel",font_size,true);
              
              text_colour_set = false;
              popStyle();
            }
  
  // Set functions
  
  void setFontSize(int t_font_size) {
    if (t_font_size < int(x_step/3.7)-2)
      scale_factor = 1;
    font_size = t_font_size;
    font = createFont("Ariel",font_size,true);      //********************************
  }
  
  void setTextColour(color t_text_colour) {
    text_colour = t_text_colour;
    text_colour_set = true;
  }

  void fontSize() {
    
    font_size = int(x_step/3.7);
    if (font_size < 6.5) {
      scale_factor = 2;
      font_size = 8;
    }
  }


  void textColour() {
      
    if (text_colour_set == false) {
      text_colour = color(255);
      color back_colour = get(x_pos,y_pos+(int)(1.5*font_size));
      if (brightness(back_colour) > 127) 
        text_colour = color(0);
    }
  }
  
  void display() {

    textColour();
    
    fill(text_colour);  
    textFont(font);
    float value;
    String label;
    textAlign(CENTER);
    
    for (int i =0; i <= num_labels/scale_factor; i++) {
      value = minimum+step_size*scale_factor*i;
      label = nf(value,0,0);
      text(label, x_pos + (x_step*scale_factor*i), y_pos+3+font_size*1.5);
    }
  }
  
}
